==> Qt6.2.4-WebAssembly-emscripten2.0.14-xLinux-x86_64-gcc8.5.0-20230613.tar.xz: Qt6.2.4-WebAssembly-emscripten2.0.14-xLinux-x86_64-gcc8.5.0/lib/cmake/Qt6QuickShapesPrivate/Qt6QuickShapesPrivateTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "Qt6::QuickShapesPrivate" for configuration "Release"
set_property(TARGET Qt6::QuickShapesPrivate APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::QuickShapesPrivate PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libQt6QuickShapes.a"
  )

list(APPEND _cmake_import_check_targets Qt6::QuickShapesPrivate )
list(APPEND _cmake_import_check_files_for_Qt6::QuickShapesPrivate "${_IMPORT_PREFIX}/lib/libQt6QuickShapes.a" )

# Import target "Qt6::QuickShapesPrivate_resources_1" for configuration "Release"
set_property(TARGET Qt6::QuickShapesPrivate_resources_1 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::QuickShapesPrivate_resources_1 PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_OBJECTS_RELEASE "${_IMPORT_PREFIX}/./qml/QtQuick/Shapes/objects-Release/QuickShapesPrivate_resources_1/.rcc/qrc_qmake_QtQuick_Shapes.cpp.o"
  )

list(APPEND _cmake_import_check_targets Qt6::QuickShapesPrivate_resources_1 )
list(APPEND _cmake_import_check_files_for_Qt6::QuickShapesPrivate_resources_1 "${_IMPORT_PREFIX}/./qml/QtQuick/Shapes/objects-Release/QuickShapesPrivate_resources_1/.rcc/qrc_qmake_QtQuick_Shapes.cpp.o" )

# Import target "Qt6::QuickShapesPrivate_resources_2" for configuration "Release"
set_property(TARGET Qt6::QuickShapesPrivate_resources_2 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::QuickShapesPrivate_resources_2 PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_OBJECTS_RELEASE "${_IMPORT_PREFIX}/lib/objects-Release/QuickShapesPrivate_resources_2/.rcc/qrc_qtquickshapes.cpp.o"
  )

list(APPEND _cmake_import_check_targets Qt6::QuickShapesPrivate_resources_2 )
list(APPEND _cmake_import_check_files_for_Qt6::QuickShapesPrivate_resources_2 "${_IMPORT_PREFIX}/lib/objects-Release/QuickShapesPrivate_resources_2/.rcc/qrc_qtquickshapes.cpp.o" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> Qt6.5.1-WebAssembly-emscripten3.1.25-xLinux-x86_64-gcc11.3.1-20230531.tar.xz: Qt6.5.1-WebAssembly-emscripten3.1.25-xLinux-x86_64-gcc11.3.1/lib/cmake/Qt6QuickShapesPrivate/Qt6QuickShapesPrivateTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "Qt6::QuickShapesPrivate" for configuration "Release"
set_property(TARGET Qt6::QuickShapesPrivate APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::QuickShapesPrivate PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libQt6QuickShapes.a"
  )

list(APPEND _cmake_import_check_targets Qt6::QuickShapesPrivate )
list(APPEND _cmake_import_check_files_for_Qt6::QuickShapesPrivate "${_IMPORT_PREFIX}/lib/libQt6QuickShapes.a" )

# Import target "Qt6::QuickShapesPrivate_resources_1" for configuration "Release"
set_property(TARGET Qt6::QuickShapesPrivate_resources_1 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::QuickShapesPrivate_resources_1 PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_OBJECTS_RELEASE "${_IMPORT_PREFIX}/./qml/QtQuick/Shapes/objects-Release/QuickShapesPrivate_resources_1/.rcc/qrc_qmake_QtQuick_Shapes.cpp.o"
  )

list(APPEND _cmake_import_check_targets Qt6::QuickShapesPrivate_resources_1 )
list(APPEND _cmake_import_check_files_for_Qt6::QuickShapesPrivate_resources_1 "${_IMPORT_PREFIX}/./qml/QtQuick/Shapes/objects-Release/QuickShapesPrivate_resources_1/.rcc/qrc_qmake_QtQuick_Shapes.cpp.o" )

# Import target "Qt6::QuickShapesPrivate_resources_2" for configuration "Release"
set_property(TARGET Qt6::QuickShapesPrivate_resources_2 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::QuickShapesPrivate_resources_2 PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_OBJECTS_RELEASE "${_IMPORT_PREFIX}/lib/objects-Release/QuickShapesPrivate_resources_2/.rcc/qrc_qtquickshapes_shaders.cpp.o"
  )

list(APPEND _cmake_import_check_targets Qt6::QuickShapesPrivate_resources_2 )
list(APPEND _cmake_import_check_files_for_Qt6::QuickShapesPrivate_resources_2 "${_IMPORT_PREFIX}/lib/objects-Release/QuickShapesPrivate_resources_2/.rcc/qrc_qtquickshapes_shaders.cpp.o" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
